@@ -34,3 +34,8 @@ from python_framework.api.src.annotation.EnumAnnotation import *
 from python_framework.api.src.service.flask.FlaskManager import *
 from python_framework.api.src.annotation.SchedulerAnnotation import *
 from python_framework.api.src.annotation.ServiceAnnotation import *
+from python_framework.api.src.annotation.RepositoryAnnotation import *
+from python_framework.api.src.annotation.ValidatorAnnotation import *
+from python_framework.api.src.annotation.MapperAnnotation import *
+from python_framework.api.src.annotation.ConverterAnnotation import *
+from python_framework.api.src.annotation.HelperAnnotation import *
